@@ -4,13 +4,14 @@ from request_handling import WebMessageHandler
 ### Mako templates
 ###
 
-def load_mako_env(template_dir, *vals):
+def load_mako_env(template_dir, *args, **kwargs):
     """Returns a function which loads a Mako templates environment.
     """
     def loader():
         from mako.lookup import TemplateLookup
         if template_dir is not None:
-            return TemplateLookup(directories=[template_dir or '.'], *vals)
+            return TemplateLookup(directories=[template_dir or '.'],
+                                  *args, **kwargs)
         else:
             return None
     return loader
@@ -77,13 +78,13 @@ class Jinja2Rendering():
 ### Tornado
 ###
 
-def load_tornado_env(template_dir):
+def load_tornado_env(template_dir, *args, **kwargs):
     """Returns a function that loads the Tornado template environment.
     """
     def loader():
         from tornado.template import Loader
         if template_dir is not None:
-            return Loader(template_dir or '.')
+            return Loader(template_dir or '.', *args, **kwargs)
         else:
             return None
     return loader
